/*
  dbi.h
  $Revision: 1.3 $
  $Date: 1996/12/13 07:07:18 $

  This is the general interface to COPPERMAN-compliant databases.

  In particular, types and type numbers are defined

  dbi.h
  Date: 1997/05/15 11:00:00 
  Jayant Kelkar (jayant@mindspring.com)
  Added support for DATE/DATETIME/INTERVAL types.
  Now they behave as expected. Created a python class IfxDTObject
  which encapsulates the details and lives in DbiDate.
*/

#ifndef DBI_H
#define DBI_H

#include "datetime.h"

#define DATE     0
#define DATETIME 1
#define INTERVAL 2
/* all nonzero types are date time */


int dbiIsDate(const PyObject *o);
int dbiIsRaw(const PyObject *o);
int dbiIsRowId(const PyObject *o);

/* These do not INCREF */
PyObject *dbiValue(PyObject *o);  
PyObject *dbiMakeDate(PyObject *contents);
PyObject *dbiMakeRaw(PyObject *contents);
PyObject *dbiMakeRowId(PyObject *contents);
PyObject *ifxMakeDateFromDate(long date, short *null);
PyObject *ifxMakeDateFromDateTime(dtime_t *data, short *null, short type);

#ifdef WINDOWS
    #ifdef DBI_EXPORT
	#define CALLCONV DL_EXPORT
    #else
	#define CALLCONV DL_IMPORT
    #endif
    #define DL_EXPORT(RTYPE) __declspec(dllexport) RTYPE
#else
#  define CALLCONV(X) X
#endif


CALLCONV(PyObject) * DbiString;
CALLCONV(PyObject) * DbiRaw;
CALLCONV(PyObject) * DbiRowId;
CALLCONV(PyObject) * DbiNumber;
CALLCONV(PyObject) * DbiDate;

CALLCONV(PyObject) * DbiNoError;
CALLCONV(PyObject) * DbiOpError;
CALLCONV(PyObject) * DbiProgError;
CALLCONV(PyObject) * DbiIntegrityError;
CALLCONV(PyObject) * DbiDataError;
CALLCONV(PyObject) * DbiInternalError;


#endif
